# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/response/response_vod.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.base.models.base import base_pb2 as base_dot_base__pb2
from volcengine.vod.models.business import vod_play_pb2 as vod_dot_business_dot_vod__play__pb2
from volcengine.vod.models.business import vod_media_pb2 as vod_dot_business_dot_vod__media__pb2
from volcengine.vod.models.business import vod_upload_pb2 as vod_dot_business_dot_vod__upload__pb2
from volcengine.vod.models.business import vod_workflow_pb2 as vod_dot_business_dot_vod__workflow__pb2
from volcengine.vod.models.business import vod_edit_pb2 as vod_dot_business_dot_vod__edit__pb2
from volcengine.vod.models.business import vod_space_pb2 as vod_dot_business_dot_vod__space__pb2
from volcengine.vod.models.business import vod_cdn_pb2 as vod_dot_business_dot_vod__cdn__pb2
from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2
from volcengine.vod.models.business import vod_smart_strategy_pb2 as vod_dot_business_dot_vod__smart__strategy__pb2
from volcengine.vod.models.business import vod_apps_manage_pb2 as vod_dot_business_dot_vod__apps__manage__pb2
from volcengine.vod.models.business import vod_measure_pb2 as vod_dot_business_dot_vod__measure__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvod/response/response_vod.proto\x12\x1eVolcengine.Vod.Models.Response\x1a\x0f\x62\x61se/base.proto\x1a\x1bvod/business/vod_play.proto\x1a\x1cvod/business/vod_media.proto\x1a\x1dvod/business/vod_upload.proto\x1a\x1fvod/business/vod_workflow.proto\x1a\x1bvod/business/vod_edit.proto\x1a\x1cvod/business/vod_space.proto\x1a\x1avod/business/vod_cdn.proto\x1a\x1dvod/business/vod_common.proto\x1a%vod/business/vod_smart_strategy.proto\x1a\"vod/business/vod_apps_manage.proto\x1a\x1evod/business/vod_measure.proto\"\xaa\x01\n\x19VodGetAllPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodAllPlayInfoResult\"\xa3\x01\n\x16VodGetPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodPlayInfoModel\"\xb7\x01\n\x1eVodGetOriginalPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetOriginalPlayInfoResult\"\xbb\x01\n VodGetPrivateDrmPlayAuthResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodGetPrivateDrmPlayAuthResult\"\xb7\x01\n\x1eVodGetHlsDecryptionKeyResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetHlsDecryptionKeyResult\"\xd3\x01\n,VodGetPlayInfoWithLiveTimeShiftSceneResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12Z\n\x06Result\x18\x02 \x01(\x0b\x32J.Volcengine.Vod.Models.Business.VodGetPlayInfoWithLiveTimeShiftSceneResult\"\xa0\x01\n\x16VodUploadMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12=\n\x06Result\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodCommitData\"\xa7\x01\n\x1eVodQueryUploadTaskInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodQueryData\"\xa3\x01\n\x14VodUrlUploadResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodUrlResponseData\"\xaf\x01\n\x1aVodApplyUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12H\n\x06Result\x18\x02 \x01(\x0b\x32\x38.Volcengine.Vod.Models.Business.VodApplyUploadInfoResult\"\xb1\x01\n\x1bVodCommitUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodCommitUploadInfoResult\"\xa9\x01\n\x18VodGetMediaInfosResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodGetMediaInfosData\"e\n\x1aVodUpdateMediaInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xaf\x01\n\x1fVodGetRecommendedPosterResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetRecPosterData\"n\n#VodUpdateMediaPublishStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xbd\x01\n\"VodUpdateMediaStorageClassResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodUpdateMediaStorageClassData\"\xa5\x01\n\x16VodDeleteMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodDeleteMediaData\"\xaf\x01\n\x1bVodDeleteTranscodesResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12G\n\x06Result\x18\x02 \x01(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodDeleteTranscodesData\"\xa7\x01\n\x17VodGetMediaListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetMediaListData\"\xb5\x01\n\x1eVodGetSubtitleInfoListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetSubtitleInfoListData\"\xb7\x01\n\x1fVodUpdateSubtitleStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodUpdateSubtitleStatusData\"h\n\x1dVodUpdateSubtitleInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xb8\x01\n!VodGetAuditFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xb5\x01\n\x1eVodGetMLFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xbf\x01\n\"VodGetBetterFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodGetBetterFramesForAuditResult\"\xb9\x01\n\x1fVodGetAudioInfoForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.VodGetAudioInfoForAuditResult\"\xdb\x01\n0VodGetAutomaticSpeechRecognitionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12^\n\x06Result\x18\x02 \x01(\x0b\x32N.Volcengine.Vod.Models.Business.VodGetAutomaticSpeechRecognitionForAuditResult\"\xcd\x01\n)VodGetAudioEventDetectionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodGetAudioEventDetectionForAuditResult\"\xc1\x01\n$VodCreateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodCreateVideoClassificationData\"o\n$VodUpdateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"o\n$VodDeleteVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xbb\x01\n#VodListVideoClassificationsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodVideoClassificationsData\"\xa4\x01\n\x18VodListSnapshotsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.VodSnapshotData\"\xa7\x01\n\x16VodGetFileListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodGetMediaInfosData\"j\n\x1fVodExtractMediaMetaTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xab\x01\n\x18VodStartWorkflowResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodStartWorkflowResult\"\xae\x01\n\"VodRetrieveTranscodeResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.TranscodeResult\"\xbb\x01\n VodListWorkflowExecutionResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodListWorkflowExecutionResult\"\xc5\x01\n%VodGetWorkflowExecutionDetailResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12S\n\x06Result\x18\x02 \x01(\x0b\x32\x43.Volcengine.Vod.Models.Business.VodGetWorkflowExecutionDetailResult\"\xb3\x01\n%VodGetWorkflowExecutionStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x41\n\x06Result\x18\x02 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.WorkflowExecution\"\xaa\x01\n\x1cVodGetWorkflowResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x41\n\x06Result\x18\x02 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodWorkflowResult\"\xc0\x01\n$VodSubmitDirectEditTaskAsyncResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12O\n\x06Result\x18\x02 \x01(\x0b\x32?.Volcengine.Vod.Models.Business.SubmitDirectEditTaskAsyncResult\"\xb2\x01\n VodGetDirectEditProgressResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x45\n\x06Result\x18\x02 \x01(\x0b\x32\x35.Volcengine.Vod.Models.Business.GetDirectEditProgress\"\xae\x01\n\x1eVodGetDirectEditResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x03(\x0b\x32\x33.Volcengine.Vod.Models.Business.GetDirectEditResult\"a\n\x16VodCreateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\x9d\x01\n\x14VodListSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"\xa2\x01\n\x19VodGetSpaceDetailResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"a\n\x16VodUpdateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"m\n\"VodUpdateSpaceUploadConfigResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xc7\x01\n&VodDescribeVodSpaceStorageDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12T\n\x06Result\x18\x02 \x01(\x0b\x32\x44.Volcengine.Vod.Models.Business.VodDescribeVodSpaceStorageDataResult\"\xa5\x01\n\x15VodListDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodDomainConfigInfo\"\xb2\x01\n\x1fVodCreateCdnRefreshTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xb2\x01\n\x1fVodCreateCdnPreloadTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xa4\x01\n\x17VodListCdnTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodCdnTaskResult\"\xb1\x01\n\x1bVodListCdnAccessLogResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodListCdnAccessLogResult\"\xb7\x01\n\x1eVodListCdnTopAccessUrlResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodListCdnTopAccessUrlResult\"\xcd\x01\n)VodDescribeVodDomainBandwidthDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodDescribeVodDomainBandwidthDataResult\"\xb7\x01\n\x1eVodCdnStatisticsCommonResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodCdnStatisticsCommonResult\"\xa2\x01\n\x19VodDescribeIPInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodCdnIpInfo\"\xc9\x01\n\'VodDescribeVodDomainTrafficDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12U\n\x06Result\x18\x02 \x01(\x0b\x32\x45.Volcengine.Vod.Models.Business.VodDescribeVodDomainTrafficDataResult\"\xb1\x01\n\x1bVodSubmitBlockTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodSubmitBlockTasksResult\"\xb9\x01\n\x1fVodGetContentBlockTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.VodGetContentBlockTasksResult\"d\n\x19VodCreateDomainV2Response\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"j\n\x1fVodUpdateDomainExpireV2Response\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"n\n#VodUpdateDomainAuthConfigV2Response\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"m\n\"VodAddCallbackSubscriptionResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"f\n\x1bVodSetCallbackEventResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xc9\x01\n\'VodGetSmartStrategyLitePlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12U\n\x06Result\x18\x02 \x01(\x0b\x32\x45.Volcengine.Vod.Models.Business.VodGetSmartStrategyLitePlayInfoResult\"\xa5\x01\n\x15VodGetAppInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetAppInfoResult\"\xc5\x01\n%DescribeVodSpaceTranscodeDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12S\n\x06Result\x18\x02 \x01(\x0b\x32\x43.Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeDataResult\"\xc3\x01\n$DescribeVodSpaceAIStatisDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12R\n\x06Result\x18\x02 \x01(\x0b\x32\x42.Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataResult\"\xcf\x01\n*DescribeVodSpaceSubtitleStatisDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12X\n\x06Result\x18\x02 \x01(\x0b\x32H.Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataResult\"\xcb\x01\n(DescribeVodSpaceDetectStatisDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12V\n\x06Result\x18\x02 \x01(\x0b\x32\x46.Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataResult\"\xb9\x01\n\x1f\x44\x65scribeVodSnapshotDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.DescribeVodSnapshotDataResultB\xcc\x01\n)com.volcengine.service.vod.model.responseB\x0bVodResponseP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Response\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETALLPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetAllPlayInfoResponse']
_VODGETPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoResponse']
_VODGETORIGINALPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetOriginalPlayInfoResponse']
_VODGETPRIVATEDRMPLAYAUTHRESPONSE = DESCRIPTOR.message_types_by_name['VodGetPrivateDrmPlayAuthResponse']
_VODGETHLSDECRYPTIONKEYRESPONSE = DESCRIPTOR.message_types_by_name['VodGetHlsDecryptionKeyResponse']
_VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoWithLiveTimeShiftSceneResponse']
_VODUPLOADMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodUploadMediaResponse']
_VODQUERYUPLOADTASKINFORESPONSE = DESCRIPTOR.message_types_by_name['VodQueryUploadTaskInfoResponse']
_VODURLUPLOADRESPONSE = DESCRIPTOR.message_types_by_name['VodUrlUploadResponse']
_VODAPPLYUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoResponse']
_VODCOMMITUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResponse']
_VODGETMEDIAINFOSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaInfosResponse']
_VODUPDATEMEDIAINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaInfoResponse']
_VODGETRECOMMENDEDPOSTERRESPONSE = DESCRIPTOR.message_types_by_name['VodGetRecommendedPosterResponse']
_VODUPDATEMEDIAPUBLISHSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaPublishStatusResponse']
_VODUPDATEMEDIASTORAGECLASSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaStorageClassResponse']
_VODDELETEMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteMediaResponse']
_VODDELETETRANSCODESRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesResponse']
_VODGETMEDIALISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaListResponse']
_VODGETSUBTITLEINFOLISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListResponse']
_VODUPDATESUBTITLESTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusResponse']
_VODUPDATESUBTITLEINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleInfoResponse']
_VODGETAUDITFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAuditFramesForAuditResponse']
_VODGETMLFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMLFramesForAuditResponse']
_VODGETBETTERFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditResponse']
_VODGETAUDIOINFOFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditResponse']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditResponse']
_VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditResponse']
_VODCREATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationResponse']
_VODUPDATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateVideoClassificationResponse']
_VODDELETEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteVideoClassificationResponse']
_VODLISTVIDEOCLASSIFICATIONSRESPONSE = DESCRIPTOR.message_types_by_name['VodListVideoClassificationsResponse']
_VODLISTSNAPSHOTSRESPONSE = DESCRIPTOR.message_types_by_name['VodListSnapshotsResponse']
_VODGETFILELISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetFileListResponse']
_VODEXTRACTMEDIAMETATASKRESPONSE = DESCRIPTOR.message_types_by_name['VodExtractMediaMetaTaskResponse']
_VODSTARTWORKFLOWRESPONSE = DESCRIPTOR.message_types_by_name['VodStartWorkflowResponse']
_VODRETRIEVETRANSCODERESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodRetrieveTranscodeResultResponse']
_VODLISTWORKFLOWEXECUTIONRESPONSE = DESCRIPTOR.message_types_by_name['VodListWorkflowExecutionResponse']
_VODGETWORKFLOWEXECUTIONDETAILRESPONSE = DESCRIPTOR.message_types_by_name['VodGetWorkflowExecutionDetailResponse']
_VODGETWORKFLOWEXECUTIONSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetWorkflowExecutionStatusResponse']
_VODGETWORKFLOWRESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetWorkflowResultResponse']
_VODSUBMITDIRECTEDITTASKASYNCRESPONSE = DESCRIPTOR.message_types_by_name['VodSubmitDirectEditTaskAsyncResponse']
_VODGETDIRECTEDITPROGRESSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetDirectEditProgressResponse']
_VODGETDIRECTEDITRESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetDirectEditResultResponse']
_VODCREATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodCreateSpaceResponse']
_VODLISTSPACERESPONSE = DESCRIPTOR.message_types_by_name['VodListSpaceResponse']
_VODGETSPACEDETAILRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSpaceDetailResponse']
_VODUPDATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceResponse']
_VODUPDATESPACEUPLOADCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceUploadConfigResponse']
_VODDESCRIBEVODSPACESTORAGEDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodSpaceStorageDataResponse']
_VODLISTDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['VodListDomainResponse']
_VODCREATECDNREFRESHTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnRefreshTaskResponse']
_VODCREATECDNPRELOADTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnPreloadTaskResponse']
_VODLISTCDNTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTasksResponse']
_VODLISTCDNACCESSLOGRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnAccessLogResponse']
_VODLISTCDNTOPACCESSURLRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTopAccessUrlResponse']
_VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainBandwidthDataResponse']
_VODCDNSTATISTICSCOMMONRESPONSE = DESCRIPTOR.message_types_by_name['VodCdnStatisticsCommonResponse']
_VODDESCRIBEIPINFORESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeIPInfoResponse']
_VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainTrafficDataResponse']
_VODSUBMITBLOCKTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodSubmitBlockTasksResponse']
_VODGETCONTENTBLOCKTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetContentBlockTasksResponse']
_VODCREATEDOMAINV2RESPONSE = DESCRIPTOR.message_types_by_name['VodCreateDomainV2Response']
_VODUPDATEDOMAINEXPIREV2RESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateDomainExpireV2Response']
_VODUPDATEDOMAINAUTHCONFIGV2RESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateDomainAuthConfigV2Response']
_VODADDCALLBACKSUBSCRIPTIONRESPONSE = DESCRIPTOR.message_types_by_name['VodAddCallbackSubscriptionResponse']
_VODSETCALLBACKEVENTRESPONSE = DESCRIPTOR.message_types_by_name['VodSetCallbackEventResponse']
_VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoResponse']
_VODGETAPPINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetAppInfoResponse']
_DESCRIBEVODSPACETRANSCODEDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceTranscodeDataResponse']
_DESCRIBEVODSPACEAISTATISDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceAIStatisDataResponse']
_DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceSubtitleStatisDataResponse']
_DESCRIBEVODSPACEDETECTSTATISDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceDetectStatisDataResponse']
_DESCRIBEVODSNAPSHOTDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSnapshotDataResponse']
VodGetAllPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetAllPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETALLPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAllPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetAllPlayInfoResponse)

VodGetPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoResponse)

VodGetOriginalPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetOriginalPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETORIGINALPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetOriginalPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetOriginalPlayInfoResponse)

VodGetPrivateDrmPlayAuthResponse = _reflection.GeneratedProtocolMessageType('VodGetPrivateDrmPlayAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPRIVATEDRMPLAYAUTHRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPrivateDrmPlayAuthResponse)
  })
_sym_db.RegisterMessage(VodGetPrivateDrmPlayAuthResponse)

VodGetHlsDecryptionKeyResponse = _reflection.GeneratedProtocolMessageType('VodGetHlsDecryptionKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETHLSDECRYPTIONKEYRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetHlsDecryptionKeyResponse)
  })
_sym_db.RegisterMessage(VodGetHlsDecryptionKeyResponse)

VodGetPlayInfoWithLiveTimeShiftSceneResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoWithLiveTimeShiftSceneResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoWithLiveTimeShiftSceneResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoWithLiveTimeShiftSceneResponse)

VodUploadMediaResponse = _reflection.GeneratedProtocolMessageType('VodUploadMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUploadMediaResponse)
  })
_sym_db.RegisterMessage(VodUploadMediaResponse)

VodQueryUploadTaskInfoResponse = _reflection.GeneratedProtocolMessageType('VodQueryUploadTaskInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADTASKINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodQueryUploadTaskInfoResponse)
  })
_sym_db.RegisterMessage(VodQueryUploadTaskInfoResponse)

VodUrlUploadResponse = _reflection.GeneratedProtocolMessageType('VodUrlUploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUrlUploadResponse)
  })
_sym_db.RegisterMessage(VodUrlUploadResponse)

VodApplyUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodApplyUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoResponse)

VodCommitUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCommitUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResponse)

VodGetMediaInfosResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaInfosResponse)
  })
_sym_db.RegisterMessage(VodGetMediaInfosResponse)

VodUpdateMediaInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaInfoResponse)

VodGetRecommendedPosterResponse = _reflection.GeneratedProtocolMessageType('VodGetRecommendedPosterResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECOMMENDEDPOSTERRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetRecommendedPosterResponse)
  })
_sym_db.RegisterMessage(VodGetRecommendedPosterResponse)

VodUpdateMediaPublishStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaPublishStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaPublishStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaPublishStatusResponse)

VodUpdateMediaStorageClassResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaStorageClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIASTORAGECLASSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaStorageClassResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaStorageClassResponse)

VodDeleteMediaResponse = _reflection.GeneratedProtocolMessageType('VodDeleteMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteMediaResponse)
  })
_sym_db.RegisterMessage(VodDeleteMediaResponse)

VodDeleteTranscodesResponse = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteTranscodesResponse)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesResponse)

VodGetMediaListResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaListResponse)
  })
_sym_db.RegisterMessage(VodGetMediaListResponse)

VodGetSubtitleInfoListResponse = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSubtitleInfoListResponse)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListResponse)

VodUpdateSubtitleStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusResponse)

VodUpdateSubtitleInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLEINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleInfoResponse)

VodGetAuditFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAuditFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDITFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAuditFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAuditFramesForAuditResponse)

VodGetMLFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetMLFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMLFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMLFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetMLFramesForAuditResponse)

VodGetBetterFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetBetterFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditResponse)

VodGetAudioInfoForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioInfoForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditResponse)

VodGetAutomaticSpeechRecognitionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAutomaticSpeechRecognitionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditResponse)

VodGetAudioEventDetectionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioEventDetectionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditResponse)

VodCreateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationResponse)

VodUpdateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodUpdateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodUpdateVideoClassificationResponse)

VodDeleteVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodDeleteVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodDeleteVideoClassificationResponse)

VodListVideoClassificationsResponse = _reflection.GeneratedProtocolMessageType('VodListVideoClassificationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTVIDEOCLASSIFICATIONSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListVideoClassificationsResponse)
  })
_sym_db.RegisterMessage(VodListVideoClassificationsResponse)

VodListSnapshotsResponse = _reflection.GeneratedProtocolMessageType('VodListSnapshotsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSNAPSHOTSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSnapshotsResponse)
  })
_sym_db.RegisterMessage(VodListSnapshotsResponse)

VodGetFileListResponse = _reflection.GeneratedProtocolMessageType('VodGetFileListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETFILELISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetFileListResponse)
  })
_sym_db.RegisterMessage(VodGetFileListResponse)

VodExtractMediaMetaTaskResponse = _reflection.GeneratedProtocolMessageType('VodExtractMediaMetaTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODEXTRACTMEDIAMETATASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodExtractMediaMetaTaskResponse)
  })
_sym_db.RegisterMessage(VodExtractMediaMetaTaskResponse)

VodStartWorkflowResponse = _reflection.GeneratedProtocolMessageType('VodStartWorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodStartWorkflowResponse)
  })
_sym_db.RegisterMessage(VodStartWorkflowResponse)

VodRetrieveTranscodeResultResponse = _reflection.GeneratedProtocolMessageType('VodRetrieveTranscodeResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODRETRIEVETRANSCODERESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodRetrieveTranscodeResultResponse)
  })
_sym_db.RegisterMessage(VodRetrieveTranscodeResultResponse)

VodListWorkflowExecutionResponse = _reflection.GeneratedProtocolMessageType('VodListWorkflowExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTWORKFLOWEXECUTIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListWorkflowExecutionResponse)
  })
_sym_db.RegisterMessage(VodListWorkflowExecutionResponse)

VodGetWorkflowExecutionDetailResponse = _reflection.GeneratedProtocolMessageType('VodGetWorkflowExecutionDetailResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETWORKFLOWEXECUTIONDETAILRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetWorkflowExecutionDetailResponse)
  })
_sym_db.RegisterMessage(VodGetWorkflowExecutionDetailResponse)

VodGetWorkflowExecutionStatusResponse = _reflection.GeneratedProtocolMessageType('VodGetWorkflowExecutionStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETWORKFLOWEXECUTIONSTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetWorkflowExecutionStatusResponse)
  })
_sym_db.RegisterMessage(VodGetWorkflowExecutionStatusResponse)

VodGetWorkflowResultResponse = _reflection.GeneratedProtocolMessageType('VodGetWorkflowResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETWORKFLOWRESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetWorkflowResultResponse)
  })
_sym_db.RegisterMessage(VodGetWorkflowResultResponse)

VodSubmitDirectEditTaskAsyncResponse = _reflection.GeneratedProtocolMessageType('VodSubmitDirectEditTaskAsyncResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSUBMITDIRECTEDITTASKASYNCRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSubmitDirectEditTaskAsyncResponse)
  })
_sym_db.RegisterMessage(VodSubmitDirectEditTaskAsyncResponse)

VodGetDirectEditProgressResponse = _reflection.GeneratedProtocolMessageType('VodGetDirectEditProgressResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETDIRECTEDITPROGRESSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetDirectEditProgressResponse)
  })
_sym_db.RegisterMessage(VodGetDirectEditProgressResponse)

VodGetDirectEditResultResponse = _reflection.GeneratedProtocolMessageType('VodGetDirectEditResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETDIRECTEDITRESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetDirectEditResultResponse)
  })
_sym_db.RegisterMessage(VodGetDirectEditResultResponse)

VodCreateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodCreateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateSpaceResponse)
  })
_sym_db.RegisterMessage(VodCreateSpaceResponse)

VodListSpaceResponse = _reflection.GeneratedProtocolMessageType('VodListSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSpaceResponse)
  })
_sym_db.RegisterMessage(VodListSpaceResponse)

VodGetSpaceDetailResponse = _reflection.GeneratedProtocolMessageType('VodGetSpaceDetailResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSPACEDETAILRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSpaceDetailResponse)
  })
_sym_db.RegisterMessage(VodGetSpaceDetailResponse)

VodUpdateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceResponse)

VodUpdateSpaceUploadConfigResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceUploadConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEUPLOADCONFIGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceUploadConfigResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceUploadConfigResponse)

VodDescribeVodSpaceStorageDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodSpaceStorageDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODSPACESTORAGEDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodSpaceStorageDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodSpaceStorageDataResponse)

VodListDomainResponse = _reflection.GeneratedProtocolMessageType('VodListDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTDOMAINRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListDomainResponse)
  })
_sym_db.RegisterMessage(VodListDomainResponse)

VodCreateCdnRefreshTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnRefreshTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNREFRESHTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnRefreshTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnRefreshTaskResponse)

VodCreateCdnPreloadTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnPreloadTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNPRELOADTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnPreloadTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnPreloadTaskResponse)

VodListCdnTasksResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTasksResponse)
  })
_sym_db.RegisterMessage(VodListCdnTasksResponse)

VodListCdnAccessLogResponse = _reflection.GeneratedProtocolMessageType('VodListCdnAccessLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNACCESSLOGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnAccessLogResponse)
  })
_sym_db.RegisterMessage(VodListCdnAccessLogResponse)

VodListCdnTopAccessUrlResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTopAccessUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTOPACCESSURLRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTopAccessUrlResponse)
  })
_sym_db.RegisterMessage(VodListCdnTopAccessUrlResponse)

VodDescribeVodDomainBandwidthDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainBandwidthDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodDomainBandwidthDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainBandwidthDataResponse)

VodCdnStatisticsCommonResponse = _reflection.GeneratedProtocolMessageType('VodCdnStatisticsCommonResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCDNSTATISTICSCOMMONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCdnStatisticsCommonResponse)
  })
_sym_db.RegisterMessage(VodCdnStatisticsCommonResponse)

VodDescribeIPInfoResponse = _reflection.GeneratedProtocolMessageType('VodDescribeIPInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEIPINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeIPInfoResponse)
  })
_sym_db.RegisterMessage(VodDescribeIPInfoResponse)

VodDescribeVodDomainTrafficDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainTrafficDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodDomainTrafficDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainTrafficDataResponse)

VodSubmitBlockTasksResponse = _reflection.GeneratedProtocolMessageType('VodSubmitBlockTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSUBMITBLOCKTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSubmitBlockTasksResponse)
  })
_sym_db.RegisterMessage(VodSubmitBlockTasksResponse)

VodGetContentBlockTasksResponse = _reflection.GeneratedProtocolMessageType('VodGetContentBlockTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETCONTENTBLOCKTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetContentBlockTasksResponse)
  })
_sym_db.RegisterMessage(VodGetContentBlockTasksResponse)

VodCreateDomainV2Response = _reflection.GeneratedProtocolMessageType('VodCreateDomainV2Response', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEDOMAINV2RESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateDomainV2Response)
  })
_sym_db.RegisterMessage(VodCreateDomainV2Response)

VodUpdateDomainExpireV2Response = _reflection.GeneratedProtocolMessageType('VodUpdateDomainExpireV2Response', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEDOMAINEXPIREV2RESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateDomainExpireV2Response)
  })
_sym_db.RegisterMessage(VodUpdateDomainExpireV2Response)

VodUpdateDomainAuthConfigV2Response = _reflection.GeneratedProtocolMessageType('VodUpdateDomainAuthConfigV2Response', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEDOMAINAUTHCONFIGV2RESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateDomainAuthConfigV2Response)
  })
_sym_db.RegisterMessage(VodUpdateDomainAuthConfigV2Response)

VodAddCallbackSubscriptionResponse = _reflection.GeneratedProtocolMessageType('VodAddCallbackSubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODADDCALLBACKSUBSCRIPTIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodAddCallbackSubscriptionResponse)
  })
_sym_db.RegisterMessage(VodAddCallbackSubscriptionResponse)

VodSetCallbackEventResponse = _reflection.GeneratedProtocolMessageType('VodSetCallbackEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSETCALLBACKEVENTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSetCallbackEventResponse)
  })
_sym_db.RegisterMessage(VodSetCallbackEventResponse)

VodGetSmartStrategyLitePlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSmartStrategyLitePlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoResponse)

VodGetAppInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetAppInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAPPINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAppInfoResponse)
  })
_sym_db.RegisterMessage(VodGetAppInfoResponse)

DescribeVodSpaceTranscodeDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceTranscodeDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACETRANSCODEDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceTranscodeDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceTranscodeDataResponse)

DescribeVodSpaceAIStatisDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceAIStatisDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEAISTATISDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceAIStatisDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceAIStatisDataResponse)

DescribeVodSpaceSubtitleStatisDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceSubtitleStatisDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceSubtitleStatisDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceSubtitleStatisDataResponse)

DescribeVodSpaceDetectStatisDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceDetectStatisDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEDETECTSTATISDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceDetectStatisDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceDetectStatisDataResponse)

DescribeVodSnapshotDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSnapshotDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSNAPSHOTDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSnapshotDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSnapshotDataResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.responseB\013VodResponseP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Response\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETALLPLAYINFORESPONSE._serialized_start=433
  _VODGETALLPLAYINFORESPONSE._serialized_end=603
  _VODGETPLAYINFORESPONSE._serialized_start=606
  _VODGETPLAYINFORESPONSE._serialized_end=769
  _VODGETORIGINALPLAYINFORESPONSE._serialized_start=772
  _VODGETORIGINALPLAYINFORESPONSE._serialized_end=955
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_start=958
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_end=1145
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_start=1148
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_end=1331
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_start=1334
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_end=1545
  _VODUPLOADMEDIARESPONSE._serialized_start=1548
  _VODUPLOADMEDIARESPONSE._serialized_end=1708
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_start=1711
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_end=1878
  _VODURLUPLOADRESPONSE._serialized_start=1881
  _VODURLUPLOADRESPONSE._serialized_end=2044
  _VODAPPLYUPLOADINFORESPONSE._serialized_start=2047
  _VODAPPLYUPLOADINFORESPONSE._serialized_end=2222
  _VODCOMMITUPLOADINFORESPONSE._serialized_start=2225
  _VODCOMMITUPLOADINFORESPONSE._serialized_end=2402
  _VODGETMEDIAINFOSRESPONSE._serialized_start=2405
  _VODGETMEDIAINFOSRESPONSE._serialized_end=2574
  _VODUPDATEMEDIAINFORESPONSE._serialized_start=2576
  _VODUPDATEMEDIAINFORESPONSE._serialized_end=2677
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_start=2680
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_end=2855
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_start=2857
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_end=2967
  _VODUPDATEMEDIASTORAGECLASSRESPONSE._serialized_start=2970
  _VODUPDATEMEDIASTORAGECLASSRESPONSE._serialized_end=3159
  _VODDELETEMEDIARESPONSE._serialized_start=3162
  _VODDELETEMEDIARESPONSE._serialized_end=3327
  _VODDELETETRANSCODESRESPONSE._serialized_start=3330
  _VODDELETETRANSCODESRESPONSE._serialized_end=3505
  _VODGETMEDIALISTRESPONSE._serialized_start=3508
  _VODGETMEDIALISTRESPONSE._serialized_end=3675
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_start=3678
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_end=3859
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_start=3862
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_end=4045
  _VODUPDATESUBTITLEINFORESPONSE._serialized_start=4047
  _VODUPDATESUBTITLEINFORESPONSE._serialized_end=4151
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_start=4154
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_end=4338
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_start=4341
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_end=4522
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_start=4525
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_end=4716
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_start=4719
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_end=4904
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_start=4907
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_end=5126
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_start=5129
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_end=5334
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5337
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5530
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5532
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5643
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5645
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5756
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_start=5759
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_end=5946
  _VODLISTSNAPSHOTSRESPONSE._serialized_start=5949
  _VODLISTSNAPSHOTSRESPONSE._serialized_end=6113
  _VODGETFILELISTRESPONSE._serialized_start=6116
  _VODGETFILELISTRESPONSE._serialized_end=6283
  _VODEXTRACTMEDIAMETATASKRESPONSE._serialized_start=6285
  _VODEXTRACTMEDIAMETATASKRESPONSE._serialized_end=6391
  _VODSTARTWORKFLOWRESPONSE._serialized_start=6394
  _VODSTARTWORKFLOWRESPONSE._serialized_end=6565
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_start=6568
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_end=6742
  _VODLISTWORKFLOWEXECUTIONRESPONSE._serialized_start=6745
  _VODLISTWORKFLOWEXECUTIONRESPONSE._serialized_end=6932
  _VODGETWORKFLOWEXECUTIONDETAILRESPONSE._serialized_start=6935
  _VODGETWORKFLOWEXECUTIONDETAILRESPONSE._serialized_end=7132
  _VODGETWORKFLOWEXECUTIONSTATUSRESPONSE._serialized_start=7135
  _VODGETWORKFLOWEXECUTIONSTATUSRESPONSE._serialized_end=7314
  _VODGETWORKFLOWRESULTRESPONSE._serialized_start=7317
  _VODGETWORKFLOWRESULTRESPONSE._serialized_end=7487
  _VODSUBMITDIRECTEDITTASKASYNCRESPONSE._serialized_start=7490
  _VODSUBMITDIRECTEDITTASKASYNCRESPONSE._serialized_end=7682
  _VODGETDIRECTEDITPROGRESSRESPONSE._serialized_start=7685
  _VODGETDIRECTEDITPROGRESSRESPONSE._serialized_end=7863
  _VODGETDIRECTEDITRESULTRESPONSE._serialized_start=7866
  _VODGETDIRECTEDITRESULTRESPONSE._serialized_end=8040
  _VODCREATESPACERESPONSE._serialized_start=8042
  _VODCREATESPACERESPONSE._serialized_end=8139
  _VODLISTSPACERESPONSE._serialized_start=8142
  _VODLISTSPACERESPONSE._serialized_end=8299
  _VODGETSPACEDETAILRESPONSE._serialized_start=8302
  _VODGETSPACEDETAILRESPONSE._serialized_end=8464
  _VODUPDATESPACERESPONSE._serialized_start=8466
  _VODUPDATESPACERESPONSE._serialized_end=8563
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_start=8565
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_end=8674
  _VODDESCRIBEVODSPACESTORAGEDATARESPONSE._serialized_start=8677
  _VODDESCRIBEVODSPACESTORAGEDATARESPONSE._serialized_end=8876
  _VODLISTDOMAINRESPONSE._serialized_start=8879
  _VODLISTDOMAINRESPONSE._serialized_end=9044
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_start=9047
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_end=9225
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_start=9228
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_end=9406
  _VODLISTCDNTASKSRESPONSE._serialized_start=9409
  _VODLISTCDNTASKSRESPONSE._serialized_end=9573
  _VODLISTCDNACCESSLOGRESPONSE._serialized_start=9576
  _VODLISTCDNACCESSLOGRESPONSE._serialized_end=9753
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_start=9756
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_end=9939
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_start=9942
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_end=10147
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_start=10150
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_end=10333
  _VODDESCRIBEIPINFORESPONSE._serialized_start=10336
  _VODDESCRIBEIPINFORESPONSE._serialized_end=10498
  _VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE._serialized_start=10501
  _VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE._serialized_end=10702
  _VODSUBMITBLOCKTASKSRESPONSE._serialized_start=10705
  _VODSUBMITBLOCKTASKSRESPONSE._serialized_end=10882
  _VODGETCONTENTBLOCKTASKSRESPONSE._serialized_start=10885
  _VODGETCONTENTBLOCKTASKSRESPONSE._serialized_end=11070
  _VODCREATEDOMAINV2RESPONSE._serialized_start=11072
  _VODCREATEDOMAINV2RESPONSE._serialized_end=11172
  _VODUPDATEDOMAINEXPIREV2RESPONSE._serialized_start=11174
  _VODUPDATEDOMAINEXPIREV2RESPONSE._serialized_end=11280
  _VODUPDATEDOMAINAUTHCONFIGV2RESPONSE._serialized_start=11282
  _VODUPDATEDOMAINAUTHCONFIGV2RESPONSE._serialized_end=11392
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_start=11394
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_end=11503
  _VODSETCALLBACKEVENTRESPONSE._serialized_start=11505
  _VODSETCALLBACKEVENTRESPONSE._serialized_end=11607
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_start=11610
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_end=11811
  _VODGETAPPINFORESPONSE._serialized_start=11814
  _VODGETAPPINFORESPONSE._serialized_end=11979
  _DESCRIBEVODSPACETRANSCODEDATARESPONSE._serialized_start=11982
  _DESCRIBEVODSPACETRANSCODEDATARESPONSE._serialized_end=12179
  _DESCRIBEVODSPACEAISTATISDATARESPONSE._serialized_start=12182
  _DESCRIBEVODSPACEAISTATISDATARESPONSE._serialized_end=12377
  _DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE._serialized_start=12380
  _DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE._serialized_end=12587
  _DESCRIBEVODSPACEDETECTSTATISDATARESPONSE._serialized_start=12590
  _DESCRIBEVODSPACEDETECTSTATISDATARESPONSE._serialized_end=12793
  _DESCRIBEVODSNAPSHOTDATARESPONSE._serialized_start=12796
  _DESCRIBEVODSNAPSHOTDATARESPONSE._serialized_end=12981
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    unbind_axyb_form = {
        "NumberPoolNo": "NP166375725010908111",
        "SubId": "S16729852979534c6e4719",
    }
    print(secretNumberService.unbind_axyb(unbind_axyb_form))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/stream_manage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!live/business/stream_manage.proto\x12\x1fVolcengine.Live.Models.Business\"\xd1\x01\n\x0eStreamInfoList\x12\n\n\x02ID\x18\x01 \x01(\x03\x12\r\n\x05Vhost\x18\x02 \x01(\t\x12\x0e\n\x06\x44omain\x18\x03 \x01(\t\x12\x0b\n\x03\x41pp\x18\x04 \x01(\t\x12\x0e\n\x06Stream\x18\x05 \x01(\t\x12\x18\n\x10SessionStartTime\x18\x06 \x01(\t\x12\x12\n\nOnlineUser\x18\x07 \x01(\x03\x12\x11\n\tBandWidth\x18\x08 \x01(\x03\x12\x0f\n\x07\x42itrate\x18\t \x01(\x03\x12\x11\n\tFramerate\x18\n \x01(\x03\x12\x12\n\nPreviewURL\x18\x0b \x01(\t\"\x82\x01\n\x0c\x43losedStream\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x0e\n\x06Stream\x18\x04 \x01(\t\x12\x11\n\tStartTime\x18\x05 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x06 \x01(\t\x12\x12\n\nSourceType\x18\x07 \x01(\t\"\x88\x01\n\x17\x46orbiddenStreamInfoList\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x0e\n\x06Stream\x18\x04 \x01(\t\x12\x12\n\nCreateTime\x18\x05 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\"m\n\x0eLiveStreamInfo\x12G\n\x0eStreamInfoList\x18\x01 \x03(\x0b\x32/.Volcengine.Live.Models.Business.StreamInfoList\x12\x12\n\nRoughCount\x18\x02 \x01(\x03\"m\n\x10\x43losedStreamInfo\x12\x45\n\x0eStreamInfoList\x18\x01 \x03(\x0b\x32-.Volcengine.Live.Models.Business.ClosedStream\x12\x12\n\nRoughCount\x18\x02 \x01(\x03\"5\n\x0fStreamStateInfo\x12\x14\n\x0cstream_state\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"{\n\x13\x46orbiddenStreamInfo\x12P\n\x0eStreamInfoList\x18\x01 \x03(\x0b\x32\x38.Volcengine.Live.Models.Business.ForbiddenStreamInfoList\x12\x12\n\nRoughCount\x18\x02 \x01(\x03\x42\xd4\x01\n*com.volcengine.service.live.model.businessB\x0cStreamManageP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_STREAMINFOLIST = DESCRIPTOR.message_types_by_name['StreamInfoList']
_CLOSEDSTREAM = DESCRIPTOR.message_types_by_name['ClosedStream']
_FORBIDDENSTREAMINFOLIST = DESCRIPTOR.message_types_by_name['ForbiddenStreamInfoList']
_LIVESTREAMINFO = DESCRIPTOR.message_types_by_name['LiveStreamInfo']
_CLOSEDSTREAMINFO = DESCRIPTOR.message_types_by_name['ClosedStreamInfo']
_STREAMSTATEINFO = DESCRIPTOR.message_types_by_name['StreamStateInfo']
_FORBIDDENSTREAMINFO = DESCRIPTOR.message_types_by_name['ForbiddenStreamInfo']
StreamInfoList = _reflection.GeneratedProtocolMessageType('StreamInfoList', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINFOLIST,
  '__module__' : 'live.business.stream_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.StreamInfoList)
  })
_sym_db.RegisterMessage(StreamInfoList)

ClosedStream = _reflection.GeneratedProtocolMessageType('ClosedStream', (_message.Message,), {
  'DESCRIPTOR' : _CLOSEDSTREAM,
  '__module__' : 'live.business.stream_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.ClosedStream)
  })
_sym_db.RegisterMessage(ClosedStream)

ForbiddenStreamInfoList = _reflection.GeneratedProtocolMessageType('ForbiddenStreamInfoList', (_message.Message,), {
  'DESCRIPTOR' : _FORBIDDENSTREAMINFOLIST,
  '__module__' : 'live.business.stream_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.ForbiddenStreamInfoList)
  })
_sym_db.RegisterMessage(ForbiddenStreamInfoList)

LiveStreamInfo = _reflection.GeneratedProtocolMessageType('LiveStreamInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIVESTREAMINFO,
  '__module__' : 'live.business.stream_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.LiveStreamInfo)
  })
_sym_db.RegisterMessage(LiveStreamInfo)

ClosedStreamInfo = _reflection.GeneratedProtocolMessageType('ClosedStreamInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOSEDSTREAMINFO,
  '__module__' : 'live.business.stream_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.ClosedStreamInfo)
  })
_sym_db.RegisterMessage(ClosedStreamInfo)

StreamStateInfo = _reflection.GeneratedProtocolMessageType('StreamStateInfo', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSTATEINFO,
  '__module__' : 'live.business.stream_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.StreamStateInfo)
  })
_sym_db.RegisterMessage(StreamStateInfo)

ForbiddenStreamInfo = _reflection.GeneratedProtocolMessageType('ForbiddenStreamInfo', (_message.Message,), {
  'DESCRIPTOR' : _FORBIDDENSTREAMINFO,
  '__module__' : 'live.business.stream_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.ForbiddenStreamInfo)
  })
_sym_db.RegisterMessage(ForbiddenStreamInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\014StreamManageP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _STREAMINFOLIST._serialized_start=71
  _STREAMINFOLIST._serialized_end=280
  _CLOSEDSTREAM._serialized_start=283
  _CLOSEDSTREAM._serialized_end=413
  _FORBIDDENSTREAMINFOLIST._serialized_start=416
  _FORBIDDENSTREAMINFOLIST._serialized_end=552
  _LIVESTREAMINFO._serialized_start=554
  _LIVESTREAMINFO._serialized_end=663
  _CLOSEDSTREAMINFO._serialized_start=665
  _CLOSEDSTREAMINFO._serialized_end=774
  _STREAMSTATEINFO._serialized_start=776
  _STREAMSTATEINFO._serialized_end=829
  _FORBIDDENSTREAMINFO._serialized_start=831
  _FORBIDDENSTREAMINFO._serialized_end=954
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from volcengine.ApiInfo import ApiInfo
from volcengine.imagex.ImageXConfig import api_info, IMAGEX_API_VERSION


def init():
    for v in ["DescribeImageXDomainTrafficData",
              "DescribeImageXDomainBandwidthData",
              "DescribeImageXBucketUsage",
              "DescribeImageXRequestCntUsage",
              "DescribeImageXBaseOpUsage",
              "DescribeImageXCompressUsage",
              "DescribeImageXEdgeRequest",
              "DescribeImageXHitRateTrafficData",
              "DescribeImageXHitRateRequestData",
              "DescribeImageXCDNTopRequestData",
              "DescribeImageXSummary",
              "DescribeImageXEdgeRequestBandwidth",
              "DescribeImageXEdgeRequestTraffic",
              "DescribeImageXEdgeRequestRegions",
              ]:
        api_info[v] = ApiInfo("GET", "/", {"Action": v, "Version": IMAGEX_API_VERSION}, {}, {})

    for v in ["DescribeImageXMirrorRequestTraffic",
              "DescribeImageXMirrorRequestBandwidth",
              "DescribeImageXMirrorRequestHttpCodeByTime",
              "DescribeImageXMirrorRequestHttpCodeOverview",
              ]:
        api_info[v] = ApiInfo("POST", "/", {"Action": v, "Version": IMAGEX_API_VERSION}, {}, {})


init()



# coding:utf-8
from __future__ import print_function

import json

from volcengine.sms.SmsService import SmsService
from volcengine.const.Const import *

if __name__ == '__main__':
    sms_service = SmsService()
    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_host('host')

    body = {
        "SmsAccount": "subAccount",
        "TemplateID": "templateId",
        # enable TemplateParam if there is template param in your template text content
        # "TemplateParam": "{\"code\": \"111\"}",
        "PhoneNumbers": "188********",
        "Tag": "tag",
    }

    body = json.dumps(body)
    resp = sms_service.send_sms(body)
    print(resp)



# coding:utf-8
from __future__ import print_function

import json

from volcengine.example.rtc.RtcService import RtcService


def set_encode():
    encode = dict()
    encode['VideoWidth'] = 1920
    encode['VideoHeight'] = 1080
    encode['VideoFps'] = 15
    encode['VideoBitrate'] = 4000
    encode['VideoCodec'] = 0
    encode['VideoGop'] = 4
    encode['AudioCodec'] = 0
    encode['AudioProfile'] = 0
    encode['AudioBitrate'] = 64
    encode['AudioSampleRate'] = 48000
    encode['AudioChannels'] = 2
    return encode


def set_layout():
    layout = dict()
    layout['LayoutMode'] = 0
    return layout


def set_control():
    control = dict()
    control['MediaType'] = 0
    control['FrameInterpolationMode'] = 0
    control['MaxIdleTime'] = 180
    control['MaxRecordTime'] = 0
    return control


def set_file_format_config():
    config = dict()
    config['FileFormat'] = ['MP4']
    return config


def set_storage_config():
    config = dict()
    config['Type'] = 0
    config['TosConfig'] = set_tos_config()
    return config


def set_tos_config():
    config = dict()
    config['AccountId'] = 'Your_AccountId'
    config['Region'] = 0
    config['Bucket'] = 'Your_Bucket'
    return config


if __name__ == '__main__':
    # using your own AK and SK
    AK = 'Your_AK'
    SK = 'Your_SK'

    # Firstly , init an RTCService Class
    rtc_service = RtcService()

    # Then , Set your AK and SK
    rtc_service.set_ak(AK)
    rtc_service.set_sk(SK)

    # You can using this API now ! Here are some Examples
    body = dict()
    body['AppId'] = 'Your_AppId'
    body['BusinessId'] = 'Your_BusinessId'
    body['RoomId'] = 'Your_RoomId'
    body['TaskId'] = 'Your_TaskId'
    body['RecordMode'] = 0
    body['Encode'] = set_encode()
    body['Layout'] = set_layout()
    body['Control'] = set_control()
    body['FileFormatConfig'] = set_file_format_config()
    body['StorageConfig'] = set_storage_config()

    body = json.dumps(body)
    resp = rtc_service.start_record(body)
    print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/request/request_live.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.live.models.business import deny_config_pb2 as live_dot_business_dot_deny__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1flive/request/request_live.proto\x12\x1eVolcengine.Live.Models.Request\x1a\x1flive/business/deny_config.proto\"C\n\x13\x43reateDomainRequest\x12\x0e\n\x06\x44omain\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x0e\n\x06Region\x18\x03 \x01(\t\"\xb3\x01\n\x17ListDomainDetailRequest\x12\x0f\n\x07PageNum\x18\x01 \x01(\x03\x12\x10\n\x08PageSize\x18\x02 \x01(\x03\x12\x11\n\tVhostList\x18\x03 \x03(\t\x12\x18\n\x10\x44omainStatusList\x18\x04 \x03(\t\x12\x16\n\x0e\x44omainTypeList\x18\x05 \x03(\t\x12\x18\n\x10\x44omainRegionList\x18\x06 \x03(\t\x12\x16\n\x0e\x44omainNameList\x18\x07 \x03(\t\"&\n\x14\x44isableDomainRequest\x12\x0e\n\x06\x44omain\x18\x01 \x01(\t\"%\n\x13\x45nableDomainRequest\x12\x0e\n\x06\x44omain\x18\x01 \x01(\t\"%\n\x13\x44\x65leteDomainRequest\x12\x0e\n\x06\x44omain\x18\x01 \x01(\t\"+\n\x15\x44\x65scribeDomainRequest\x12\x12\n\nDomainList\x18\x01 \x03(\t\"J\n ManagerPullPushDomainBindRequest\x12\x12\n\nPullDomain\x18\x01 \x01(\t\x12\x12\n\nPushDomain\x18\x02 \x01(\t\"\xa5\x01\n$DescribeRecordTaskFileHistoryRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\x12\x0e\n\x06Stream\x18\x03 \x01(\t\x12\x10\n\x08\x44\x61teFrom\x18\x04 \x01(\t\x12\x0e\n\x06\x44\x61teTo\x18\x05 \x01(\t\x12\x0f\n\x07PageNum\x18\x06 \x01(\x05\x12\x10\n\x08PageSize\x18\x07 \x01(\x05\x12\x0c\n\x04Type\x18\x08 \x01(\t\"\xa2\x01\n!DescribeCDNSnapshotHistoryRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\x12\x0e\n\x06Stream\x18\x03 \x01(\t\x12\x10\n\x08\x44\x61teFrom\x18\x04 \x01(\t\x12\x0e\n\x06\x44\x61teTo\x18\x05 \x01(\t\x12\x0f\n\x07PageNum\x18\x06 \x01(\x05\x12\x10\n\x08PageSize\x18\x07 \x01(\x05\x12\x0c\n\x04Type\x18\x08 \x01(\t\"\xaa\x01\n#DescribeLiveStreamInfoByPageRequest\x12\x0f\n\x07PageNum\x18\x01 \x01(\x05\x12\x10\n\x08PageSize\x18\x02 \x01(\x05\x12\r\n\x05Vhost\x18\x03 \x01(\t\x12\x0e\n\x06\x44omain\x18\x04 \x01(\t\x12\x0b\n\x03\x41pp\x18\x05 \x01(\t\x12\x0e\n\x06Stream\x18\x06 \x01(\t\x12\x12\n\nStreamType\x18\x07 \x01(\t\x12\x10\n\x08InfoType\x18\x08 \x01(\t\"\xd0\x01\n%DescribeClosedStreamInfoByPageRequest\x12\x0f\n\x07PageNum\x18\x01 \x01(\x05\x12\x10\n\x08PageSize\x18\x02 \x01(\x05\x12\r\n\x05Vhost\x18\x03 \x01(\t\x12\x0e\n\x06\x44omain\x18\x04 \x01(\t\x12\x0b\n\x03\x41pp\x18\x05 \x01(\t\x12\x0e\n\x06Stream\x18\x06 \x01(\t\x12\x0c\n\x04Sort\x18\x07 \x01(\t\x12\x13\n\x0b\x45ndTimeFrom\x18\x08 \x01(\t\x12\x11\n\tEndTimeTo\x18\t \x01(\t\x12\x12\n\nSourceType\x18\n \x01(\t\"\x87\x01\n(DescribeForbiddenStreamInfoByPageRequest\x12\x0f\n\x07PageNum\x18\x01 \x01(\x05\x12\x10\n\x08PageSize\x18\x02 \x01(\x05\x12\r\n\x05Vhost\x18\x03 \x01(\t\x12\x0b\n\x03\x41pp\x18\x04 \x01(\t\x12\x0e\n\x06Stream\x18\x05 \x01(\t\x12\x0c\n\x04Sort\x18\x06 \x01(\t\"\\\n\x1e\x44\x65scribeLiveStreamStateRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x0e\n\x06Stream\x18\x04 \x01(\t\"Q\n\x13ResumeStreamRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x0e\n\x06Stream\x18\x04 \x01(\t\"?\n\x11KillStreamRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\x12\x0e\n\x06Stream\x18\x03 \x01(\t\"b\n\x13\x46orbidStreamRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x0e\n\x06Stream\x18\x04 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x05 \x01(\t\"\x98\x02\n\x18UpdateRelaySourceRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\x12\x1d\n\x15RelaySourceDomainList\x18\x03 \x03(\t\x12j\n\x11RelaySourceParams\x18\x04 \x03(\x0b\x32O.Volcengine.Live.Models.Request.UpdateRelaySourceRequest.RelaySourceParamsEntry\x12\x1b\n\x13RelaySourceProtocol\x18\x05 \x01(\t\x1a\x38\n\x16RelaySourceParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x18\x44\x65leteRelaySourceRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\"+\n\x1a\x44\x65scribeRelaySourceRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\"~\n\x18\x43reateVQScoreTaskRequest\x12\x10\n\x08MainAddr\x18\x01 \x01(\t\x12\x14\n\x0c\x43ontrastAddr\x18\x02 \x01(\t\x12\x15\n\rFrameInterval\x18\x03 \x01(\x05\x12\x10\n\x08\x44uration\x18\x04 \x01(\x05\x12\x11\n\tAlgorithm\x18\x05 \x01(\t\"(\n\x1a\x44\x65scribeVQScoreTaskRequest\x12\n\n\x02ID\x18\x01 \x01(\t\"o\n\x16ListVQScoreTaskRequest\x12\x11\n\tStartTime\x18\x01 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x02 \x01(\t\x12\x0f\n\x07PageNum\x18\x03 \x01(\x05\x12\x10\n\x08PageSize\x18\x04 \x01(\x05\x12\x0e\n\x06Status\x18\x05 \x01(\x05\"\x9e\x01\n\x16GeneratePlayURLRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x0e\n\x06Stream\x18\x04 \x01(\t\x12\x0e\n\x06Suffix\x18\x05 \x01(\t\x12\x0c\n\x04Type\x18\x06 \x01(\t\x12\x15\n\rValidDuration\x18\x07 \x01(\x03\x12\x13\n\x0b\x45xpiredTime\x18\x08 \x01(\t\"\x80\x01\n\x16GeneratePushURLRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x0e\n\x06Stream\x18\x04 \x01(\t\x12\x15\n\rValidDuration\x18\x05 \x01(\x03\x12\x13\n\x0b\x45xpiredTime\x18\x06 \x01(\t\"\xba\x01\n\x1b\x43reatePullToPushTaskRequest\x12\r\n\x05Title\x18\x01 \x01(\t\x12\x11\n\tStartTime\x18\x02 \x01(\x03\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\x03\x12\x13\n\x0b\x43\x61llbackURL\x18\x04 \x01(\t\x12\x0c\n\x04Type\x18\x05 \x01(\x05\x12\x11\n\tCycleMode\x18\x06 \x01(\x05\x12\x0f\n\x07\x44stAddr\x18\x07 \x01(\t\x12\x0f\n\x07SrcAddr\x18\x08 \x01(\t\x12\x10\n\x08SrcAddrS\x18\t \x03(\t\"F\n\x19ListPullToPushTaskRequest\x12\x0c\n\x04Page\x18\x01 \x01(\x05\x12\x0c\n\x04Size\x18\x02 \x01(\x05\x12\r\n\x05Title\x18\x03 \x01(\t\"\xca\x01\n\x1bUpdatePullToPushTaskRequest\x12\r\n\x05Title\x18\x01 \x01(\t\x12\x0e\n\x06TaskId\x18\x02 \x01(\t\x12\x11\n\tStartTime\x18\x03 \x01(\x03\x12\x0f\n\x07\x45ndTime\x18\x04 \x01(\x03\x12\x13\n\x0b\x43\x61llbackURL\x18\x05 \x01(\t\x12\x0c\n\x04Type\x18\x06 \x01(\x05\x12\x11\n\tCycleMode\x18\x07 \x01(\x05\x12\x0f\n\x07\x44stAddr\x18\x08 \x01(\t\x12\x0f\n\x07SrcAddr\x18\t \x01(\t\x12\x10\n\x08SrcAddrS\x18\n \x03(\t\".\n\x1cRestartPullToPushTaskRequest\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\"+\n\x19StopPullToPushTaskRequest\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\"-\n\x1b\x44\x65letePullToPushTaskRequest\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\"\x90\x01\n\x17UpdateDenyConfigRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12I\n\x0e\x44\x65nyConfigList\x18\x04 \x03(\x0b\x32\x31.Volcengine.Live.Models.Business.DenyConfigDetail\"G\n\x19\x44\x65scribeDenyConfigRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\"E\n\x17\x44\x65leteDenyConfigRequest\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\tB\xcd\x01\n)com.volcengine.service.live.model.requestB\x0bLiveRequestP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/live/models/request\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Live\\Models\\Request\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_CREATEDOMAINREQUEST = DESCRIPTOR.message_types_by_name['CreateDomainRequest']
_LISTDOMAINDETAILREQUEST = DESCRIPTOR.message_types_by_name['ListDomainDetailRequest']
_DISABLEDOMAINREQUEST = DESCRIPTOR.message_types_by_name['DisableDomainRequest']
_ENABLEDOMAINREQUEST = DESCRIPTOR.message_types_by_name['EnableDomainRequest']
_DELETEDOMAINREQUEST = DESCRIPTOR.message_types_by_name['DeleteDomainRequest']
_DESCRIBEDOMAINREQUEST = DESCRIPTOR.message_types_by_name['DescribeDomainRequest']
_MANAGERPULLPUSHDOMAINBINDREQUEST = DESCRIPTOR.message_types_by_name['ManagerPullPushDomainBindRequest']
_DESCRIBERECORDTASKFILEHISTORYREQUEST = DESCRIPTOR.message_types_by_name['DescribeRecordTaskFileHistoryRequest']
_DESCRIBECDNSNAPSHOTHISTORYREQUEST = DESCRIPTOR.message_types_by_name['DescribeCDNSnapshotHistoryRequest']
_DESCRIBELIVESTREAMINFOBYPAGEREQUEST = DESCRIPTOR.message_types_by_name['DescribeLiveStreamInfoByPageRequest']
_DESCRIBECLOSEDSTREAMINFOBYPAGEREQUEST = DESCRIPTOR.message_types_by_name['DescribeClosedStreamInfoByPageRequest']
_DESCRIBEFORBIDDENSTREAMINFOBYPAGEREQUEST = DESCRIPTOR.message_types_by_name['DescribeForbiddenStreamInfoByPageRequest']
_DESCRIBELIVESTREAMSTATEREQUEST = DESCRIPTOR.message_types_by_name['DescribeLiveStreamStateRequest']
_RESUMESTREAMREQUEST = DESCRIPTOR.message_types_by_name['ResumeStreamRequest']
_KILLSTREAMREQUEST = DESCRIPTOR.message_types_by_name['KillStreamRequest']
_FORBIDSTREAMREQUEST = DESCRIPTOR.message_types_by_name['ForbidStreamRequest']
_UPDATERELAYSOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateRelaySourceRequest']
_UPDATERELAYSOURCEREQUEST_RELAYSOURCEPARAMSENTRY = _UPDATERELAYSOURCEREQUEST.nested_types_by_name['RelaySourceParamsEntry']
_DELETERELAYSOURCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteRelaySourceRequest']
_DESCRIBERELAYSOURCEREQUEST = DESCRIPTOR.message_types_by_name['DescribeRelaySourceRequest']
# _CREATEVQSCORETASKREQUEST = DESCRIPTOR.message_types_by_name['CreateVQScoreTaskRequest']
_DESCRIBEVQSCORETASKREQUEST = DESCRIPTOR.message_types_by_name['DescribeVQScoreTaskRequest']
_LISTVQSCORETASKREQUEST = DESCRIPTOR.message_types_by_name['ListVQScoreTaskRequest']
# _GENERATEPLAYURLREQUEST = DESCRIPTOR.message_types_by_name['GeneratePlayURLRequest']
# _GENERATEPUSHURLREQUEST = DESCRIPTOR.message_types_by_name['GeneratePushURLRequest']
# _CREATEPULLTOPUSHTASKREQUEST = DESCRIPTOR.message_types_by_name['CreatePullToPushTaskRequest']
_LISTPULLTOPUSHTASKREQUEST = DESCRIPTOR.message_types_by_name['ListPullToPushTaskRequest']
# _UPDATEPULLTOPUSHTASKREQUEST = DESCRIPTOR.message_types_by_name['UpdatePullToPushTaskRequest']
_RESTARTPULLTOPUSHTASKREQUEST = DESCRIPTOR.message_types_by_name['RestartPullToPushTaskRequest']
_STOPPULLTOPUSHTASKREQUEST = DESCRIPTOR.message_types_by_name['StopPullToPushTaskRequest']
_DELETEPULLTOPUSHTASKREQUEST = DESCRIPTOR.message_types_by_name['DeletePullToPushTaskRequest']
_UPDATEDENYCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateDenyConfigRequest']
_DESCRIBEDENYCONFIGREQUEST = DESCRIPTOR.message_types_by_name['DescribeDenyConfigRequest']
_DELETEDENYCONFIGREQUEST = DESCRIPTOR.message_types_by_name['DeleteDenyConfigRequest']
CreateDomainRequest = _reflection.GeneratedProtocolMessageType('CreateDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOMAINREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.CreateDomainRequest)
  })
_sym_db.RegisterMessage(CreateDomainRequest)

ListDomainDetailRequest = _reflection.GeneratedProtocolMessageType('ListDomainDetailRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDOMAINDETAILREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.ListDomainDetailRequest)
  })
_sym_db.RegisterMessage(ListDomainDetailRequest)

DisableDomainRequest = _reflection.GeneratedProtocolMessageType('DisableDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEDOMAINREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DisableDomainRequest)
  })
_sym_db.RegisterMessage(DisableDomainRequest)

EnableDomainRequest = _reflection.GeneratedProtocolMessageType('EnableDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEDOMAINREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.EnableDomainRequest)
  })
_sym_db.RegisterMessage(EnableDomainRequest)

DeleteDomainRequest = _reflection.GeneratedProtocolMessageType('DeleteDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDOMAINREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DeleteDomainRequest)
  })
_sym_db.RegisterMessage(DeleteDomainRequest)

DescribeDomainRequest = _reflection.GeneratedProtocolMessageType('DescribeDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDOMAINREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeDomainRequest)
  })
_sym_db.RegisterMessage(DescribeDomainRequest)

ManagerPullPushDomainBindRequest = _reflection.GeneratedProtocolMessageType('ManagerPullPushDomainBindRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGERPULLPUSHDOMAINBINDREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.ManagerPullPushDomainBindRequest)
  })
_sym_db.RegisterMessage(ManagerPullPushDomainBindRequest)

DescribeRecordTaskFileHistoryRequest = _reflection.GeneratedProtocolMessageType('DescribeRecordTaskFileHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERECORDTASKFILEHISTORYREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeRecordTaskFileHistoryRequest)
  })
_sym_db.RegisterMessage(DescribeRecordTaskFileHistoryRequest)

DescribeCDNSnapshotHistoryRequest = _reflection.GeneratedProtocolMessageType('DescribeCDNSnapshotHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECDNSNAPSHOTHISTORYREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeCDNSnapshotHistoryRequest)
  })
_sym_db.RegisterMessage(DescribeCDNSnapshotHistoryRequest)

DescribeLiveStreamInfoByPageRequest = _reflection.GeneratedProtocolMessageType('DescribeLiveStreamInfoByPageRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELIVESTREAMINFOBYPAGEREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeLiveStreamInfoByPageRequest)
  })
_sym_db.RegisterMessage(DescribeLiveStreamInfoByPageRequest)

DescribeClosedStreamInfoByPageRequest = _reflection.GeneratedProtocolMessageType('DescribeClosedStreamInfoByPageRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECLOSEDSTREAMINFOBYPAGEREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeClosedStreamInfoByPageRequest)
  })
_sym_db.RegisterMessage(DescribeClosedStreamInfoByPageRequest)

DescribeForbiddenStreamInfoByPageRequest = _reflection.GeneratedProtocolMessageType('DescribeForbiddenStreamInfoByPageRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEFORBIDDENSTREAMINFOBYPAGEREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeForbiddenStreamInfoByPageRequest)
  })
_sym_db.RegisterMessage(DescribeForbiddenStreamInfoByPageRequest)

DescribeLiveStreamStateRequest = _reflection.GeneratedProtocolMessageType('DescribeLiveStreamStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELIVESTREAMSTATEREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeLiveStreamStateRequest)
  })
_sym_db.RegisterMessage(DescribeLiveStreamStateRequest)

ResumeStreamRequest = _reflection.GeneratedProtocolMessageType('ResumeStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMESTREAMREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.ResumeStreamRequest)
  })
_sym_db.RegisterMessage(ResumeStreamRequest)

KillStreamRequest = _reflection.GeneratedProtocolMessageType('KillStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _KILLSTREAMREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.KillStreamRequest)
  })
_sym_db.RegisterMessage(KillStreamRequest)

ForbidStreamRequest = _reflection.GeneratedProtocolMessageType('ForbidStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _FORBIDSTREAMREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.ForbidStreamRequest)
  })
_sym_db.RegisterMessage(ForbidStreamRequest)

UpdateRelaySourceRequest = _reflection.GeneratedProtocolMessageType('UpdateRelaySourceRequest', (_message.Message,), {

  'RelaySourceParamsEntry' : _reflection.GeneratedProtocolMessageType('RelaySourceParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATERELAYSOURCEREQUEST_RELAYSOURCEPARAMSENTRY,
    '__module__' : 'live.request.request_live_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.UpdateRelaySourceRequest.RelaySourceParamsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATERELAYSOURCEREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.UpdateRelaySourceRequest)
  })
_sym_db.RegisterMessage(UpdateRelaySourceRequest)
_sym_db.RegisterMessage(UpdateRelaySourceRequest.RelaySourceParamsEntry)

DeleteRelaySourceRequest = _reflection.GeneratedProtocolMessageType('DeleteRelaySourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERELAYSOURCEREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DeleteRelaySourceRequest)
  })
_sym_db.RegisterMessage(DeleteRelaySourceRequest)

DescribeRelaySourceRequest = _reflection.GeneratedProtocolMessageType('DescribeRelaySourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERELAYSOURCEREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeRelaySourceRequest)
  })
_sym_db.RegisterMessage(DescribeRelaySourceRequest)

# CreateVQScoreTaskRequest = _reflection.GeneratedProtocolMessageType('CreateVQScoreTaskRequest', (_message.Message,), {
#   'DESCRIPTOR' : _CREATEVQSCORETASKREQUEST,
#   '__module__' : 'live.request.request_live_pb2'
#   # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.CreateVQScoreTaskRequest)
#   })
# _sym_db.RegisterMessage(CreateVQScoreTaskRequest)

DescribeVQScoreTaskRequest = _reflection.GeneratedProtocolMessageType('DescribeVQScoreTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVQSCORETASKREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeVQScoreTaskRequest)
  })
_sym_db.RegisterMessage(DescribeVQScoreTaskRequest)

ListVQScoreTaskRequest = _reflection.GeneratedProtocolMessageType('ListVQScoreTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVQSCORETASKREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.ListVQScoreTaskRequest)
  })
_sym_db.RegisterMessage(ListVQScoreTaskRequest)

# GeneratePlayURLRequest = _reflection.GeneratedProtocolMessageType('GeneratePlayURLRequest', (_message.Message,), {
#   'DESCRIPTOR' : _GENERATEPLAYURLREQUEST,
#   '__module__' : 'live.request.request_live_pb2'
#   # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.GeneratePlayURLRequest)
#   })
# _sym_db.RegisterMessage(GeneratePlayURLRequest)

# GeneratePushURLRequest = _reflection.GeneratedProtocolMessageType('GeneratePushURLRequest', (_message.Message,), {
#   'DESCRIPTOR' : _GENERATEPUSHURLREQUEST,
#   '__module__' : 'live.request.request_live_pb2'
#   # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.GeneratePushURLRequest)
#   })
# _sym_db.RegisterMessage(GeneratePushURLRequest)

# CreatePullToPushTaskRequest = _reflection.GeneratedProtocolMessageType('CreatePullToPushTaskRequest', (_message.Message,), {
#   'DESCRIPTOR' : _CREATEPULLTOPUSHTASKREQUEST,
#   '__module__' : 'live.request.request_live_pb2'
#   # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.CreatePullToPushTaskRequest)
#   })
# _sym_db.RegisterMessage(CreatePullToPushTaskRequest)

ListPullToPushTaskRequest = _reflection.GeneratedProtocolMessageType('ListPullToPushTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPULLTOPUSHTASKREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.ListPullToPushTaskRequest)
  })
_sym_db.RegisterMessage(ListPullToPushTaskRequest)

# UpdatePullToPushTaskRequest = _reflection.GeneratedProtocolMessageType('UpdatePullToPushTaskRequest', (_message.Message,), {
#   'DESCRIPTOR' : _UPDATEPULLTOPUSHTASKREQUEST,
#   '__module__' : 'live.request.request_live_pb2'
#   # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.UpdatePullToPushTaskRequest)
#   })
# _sym_db.RegisterMessage(UpdatePullToPushTaskRequest)

RestartPullToPushTaskRequest = _reflection.GeneratedProtocolMessageType('RestartPullToPushTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTPULLTOPUSHTASKREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.RestartPullToPushTaskRequest)
  })
_sym_db.RegisterMessage(RestartPullToPushTaskRequest)

StopPullToPushTaskRequest = _reflection.GeneratedProtocolMessageType('StopPullToPushTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPPULLTOPUSHTASKREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.StopPullToPushTaskRequest)
  })
_sym_db.RegisterMessage(StopPullToPushTaskRequest)

DeletePullToPushTaskRequest = _reflection.GeneratedProtocolMessageType('DeletePullToPushTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPULLTOPUSHTASKREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DeletePullToPushTaskRequest)
  })
_sym_db.RegisterMessage(DeletePullToPushTaskRequest)

UpdateDenyConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateDenyConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDENYCONFIGREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.UpdateDenyConfigRequest)
  })
_sym_db.RegisterMessage(UpdateDenyConfigRequest)

DescribeDenyConfigRequest = _reflection.GeneratedProtocolMessageType('DescribeDenyConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDENYCONFIGREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DescribeDenyConfigRequest)
  })
_sym_db.RegisterMessage(DescribeDenyConfigRequest)

DeleteDenyConfigRequest = _reflection.GeneratedProtocolMessageType('DeleteDenyConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDENYCONFIGREQUEST,
  '__module__' : 'live.request.request_live_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Request.DeleteDenyConfigRequest)
  })
_sym_db.RegisterMessage(DeleteDenyConfigRequest)


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.live.model.requestB\013LiveRequestP\001ZAgithub.com/volcengine/volc-sdk-golang/service/live/models/request\240\001\001\330\001\001\312\002 Volc\\Service\\Live\\Models\\Request\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _UPDATERELAYSOURCEREQUEST_RELAYSOURCEPARAMSENTRY._options = None
  _UPDATERELAYSOURCEREQUEST_RELAYSOURCEPARAMSENTRY._serialized_options = b'8\001'
  _CREATEDOMAINREQUEST._serialized_start=100
  _CREATEDOMAINREQUEST._serialized_end=167
  _LISTDOMAINDETAILREQUEST._serialized_start=170
  _LISTDOMAINDETAILREQUEST._serialized_end=349
  _DISABLEDOMAINREQUEST._serialized_start=351
  _DISABLEDOMAINREQUEST._serialized_end=389
  _ENABLEDOMAINREQUEST._serialized_start=391
  _ENABLEDOMAINREQUEST._serialized_end=428
  _DELETEDOMAINREQUEST._serialized_start=430
  _DELETEDOMAINREQUEST._serialized_end=467
  _DESCRIBEDOMAINREQUEST._serialized_start=469
  _DESCRIBEDOMAINREQUEST._serialized_end=512
  _MANAGERPULLPUSHDOMAINBINDREQUEST._serialized_start=514
  _MANAGERPULLPUSHDOMAINBINDREQUEST._serialized_end=588
  _DESCRIBERECORDTASKFILEHISTORYREQUEST._serialized_start=591
  _DESCRIBERECORDTASKFILEHISTORYREQUEST._serialized_end=756
  _DESCRIBECDNSNAPSHOTHISTORYREQUEST._serialized_start=759
  _DESCRIBECDNSNAPSHOTHISTORYREQUEST._serialized_end=921
  _DESCRIBELIVESTREAMINFOBYPAGEREQUEST._serialized_start=924
  _DESCRIBELIVESTREAMINFOBYPAGEREQUEST._serialized_end=1094
  _DESCRIBECLOSEDSTREAMINFOBYPAGEREQUEST._serialized_start=1097
  _DESCRIBECLOSEDSTREAMINFOBYPAGEREQUEST._serialized_end=1305
  _DESCRIBEFORBIDDENSTREAMINFOBYPAGEREQUEST._serialized_start=1308
  _DESCRIBEFORBIDDENSTREAMINFOBYPAGEREQUEST._serialized_end=1443
  _DESCRIBELIVESTREAMSTATEREQUEST._serialized_start=1445
  _DESCRIBELIVESTREAMSTATEREQUEST._serialized_end=1537
  _RESUMESTREAMREQUEST._serialized_start=1539
  _RESUMESTREAMREQUEST._serialized_end=1620
  _KILLSTREAMREQUEST._serialized_start=1622
  _KILLSTREAMREQUEST._serialized_end=1685
  _FORBIDSTREAMREQUEST._serialized_start=1687
  _FORBIDSTREAMREQUEST._serialized_end=1785
  _UPDATERELAYSOURCEREQUEST._serialized_start=1788
  _UPDATERELAYSOURCEREQUEST._serialized_end=2068
  _UPDATERELAYSOURCEREQUEST_RELAYSOURCEPARAMSENTRY._serialized_start=2012
  _UPDATERELAYSOURCEREQUEST_RELAYSOURCEPARAMSENTRY._serialized_end=2068
  _DELETERELAYSOURCEREQUEST._serialized_start=2070
  _DELETERELAYSOURCEREQUEST._serialized_end=2124
  _DESCRIBERELAYSOURCEREQUEST._serialized_start=2126
  _DESCRIBERELAYSOURCEREQUEST._serialized_end=2169
  # _CREATEVQSCORETASKREQUEST._serialized_start=2171
  # _CREATEVQSCORETASKREQUEST._serialized_end=2297
  _DESCRIBEVQSCORETASKREQUEST._serialized_start=2299
  _DESCRIBEVQSCORETASKREQUEST._serialized_end=2339
  _LISTVQSCORETASKREQUEST._serialized_start=2341
  _LISTVQSCORETASKREQUEST._serialized_end=2452
  # _GENERATEPLAYURLREQUEST._serialized_start=2455
  # _GENERATEPLAYURLREQUEST._serialized_end=2613
  # _GENERATEPUSHURLREQUEST._serialized_start=2616
  # _GENERATEPUSHURLREQUEST._serialized_end=2744
  # _CREATEPULLTOPUSHTASKREQUEST._serialized_start=2747
  # _CREATEPULLTOPUSHTASKREQUEST._serialized_end=2933
  _LISTPULLTOPUSHTASKREQUEST._serialized_start=2935
  _LISTPULLTOPUSHTASKREQUEST._serialized_end=3005
  # _UPDATEPULLTOPUSHTASKREQUEST._serialized_start=3008
  # _UPDATEPULLTOPUSHTASKREQUEST._serialized_end=3210
  _RESTARTPULLTOPUSHTASKREQUEST._serialized_start=3212
  _RESTARTPULLTOPUSHTASKREQUEST._serialized_end=3258
  _STOPPULLTOPUSHTASKREQUEST._serialized_start=3260
  _STOPPULLTOPUSHTASKREQUEST._serialized_end=3303
  _DELETEPULLTOPUSHTASKREQUEST._serialized_start=3305
  _DELETEPULLTOPUSHTASKREQUEST._serialized_end=3350
  _UPDATEDENYCONFIGREQUEST._serialized_start=3353
  _UPDATEDENYCONFIGREQUEST._serialized_end=3497
  _DESCRIBEDENYCONFIGREQUEST._serialized_start=3499
  _DESCRIBEDENYCONFIGREQUEST._serialized_end=3570
  _DELETEDENYCONFIGREQUEST._serialized_start=3572
  _DELETEDENYCONFIGREQUEST._serialized_end=3641
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    bind_axne_form = {
        "NumberPoolNo": "NP167091934402820309",
        "PhoneNoA": "13700000017",
        "PhoneNoB": "13700000018",
        "UserData": "this is my user data",
        "CityCode": "010",
        "ExpireTime":"1673071556",
    }
    print(secretNumberService.bind_axne(bind_axne_form))
